liveplots
=========

This is a python package which serves a (so far very minimalistic) plotting API through a xmlrpc server. The plots are generated by Gnuplot.



This is a python package which serves a (so far very minimalistic) plotting API through a xmlrpc server. The plots are generated by Gnuplot.

The purpose of this package is to monitor long running computations without interfering with it, i.e. slowing it down.

Multiple plot servers can be started, each one on its separate daemon process.

a simple example can be found here:

https://github.com/fccoelho/liveplots/blob/master/Examples/simple.py

A file system monitor is also offered in the package. Example usage is below.

https://github.com/fccoelho/liveplots/blob/master/Examples/monitor.py
